@@ -185,7 +185,7 @@ migemo* gMigemo;
 
 void migemo_init()
 {
-    setenv("COMPLETION_ENABLE_MIGEMO", 1, 1);
+    setenv("COMPLETION_ENABLE_MIGEMO", "1", 1);
 
     char buf[PATH_MAX];
     char migemodir[PATH_MAX];
