@@ -1967,7 +1967,10 @@ void msave_screen()
     snprintf(buf, 128, "\033%d\033[?47h", 7);
     ttywrite(buf);
 #else
-    ttywrite(tigetstr("smcup"));
+    char* str = tigetstr("smcup");
+    if(str) {
+        ttywrite(str);
+    }
 #endif
 }
 
@@ -1978,7 +1981,10 @@ void mrestore_screen()
     snprintf(buf, 128, "\033[2J\033[?47l\033%d", 8);
     ttywrite(buf);
 #else
-    ttywrite(tigetstr("rmcup"));
+    char* str = tigetstr("rmcup");
+    if(str) {
+        ttywrite(str);
+    }
 #endif
 }
 
