@@ -8,26 +8,18 @@
 #include "saphire_extra.h"
 #include <stdlib.h>
 
-#if defined(HAVE_GC_H) || defined(HAVE_GC_GC_H)
-
-#ifdef HAVE_GC_H
-#include <gc.h>
-#endif
-
-#ifdef HAVE_GC_GC_H
-#include <gc/gc.h>
-#endif
+#if !defined(MDEBUG)
 
 #   define CHECKML_BEGIN()
 #   define CHECKML_END()  
-#   define MALLOC(o) GC_malloc(o)
-#   define STRDUP(o) GC_strdup(o)
-#   define REALLOC(o, o2) GC_realloc(o, o2)
-#   define FREE(o)
+#   define MALLOC(o) malloc(o)
+#   define STRDUP(o) strdup(o)
+#   define REALLOC(o, o2) realloc(o, o2)
+#   define FREE(o) free(o)
 #   define TIMER_BEGIN(msg)
 #   define TIMER_END()
 
-#elif defined(MDEBUG)
+#else 
 
 /* [N`FbNp֐ */
 void CheckMemLeak_Begin();      // 
@@ -56,17 +48,6 @@ void timer_count_end(const char* file, int line, const char* fun);
 #   define TIMER_BEGIN(msg) timer_count_start(msg)
 #   define TIMER_END() timer_count_end(__FILE__, __LINE__, __FUNCTION__)
 
-#else
-
-#   define CHECKML_BEGIN()
-#   define CHECKML_END()  
-#   define MALLOC(o) malloc(o)
-#   define STRDUP(o) strdup(o)
-#   define REALLOC(o, o2) realloc(o, o2)
-#   define FREE(o) free(o)
-#   define TIMER_BEGIN(msg)
-#   define TIMER_END()
-
 #endif
 
 #endif
