@@ -1,5 +1,6 @@
 #include "config.h"
 #include "saphire_hash.h"
+#include "saphire_vector.h"
 #include "saphire_debug.h"
 #include <stdio.h>
 #include <string.h>
@@ -31,7 +32,7 @@ static void hash_it_release(hash_it* self)
 ///////////////////////////////////////////////////////////////////////
 // 
 ///////////////////////////////////////////////////////////////////////
-#if defined(MDEBUG) && !defined(HAVE_GC_H) && !defined(HAVE_GC_GC_H)
+#if defined(MDEBUG)
 
 hash_obj* hash_new_debug(int size, const char* fname, int line, const char* func_name)
 {
@@ -70,7 +71,6 @@ hash_obj* hash_new(int size)
 ///////////////////////////////////////////////////////////////////////
 // 
 ///////////////////////////////////////////////////////////////////////
-/*
 void hash_delete(hash_obj* self)
 {
    hash_it* it = self->mEntryIt;
@@ -85,7 +85,6 @@ void hash_delete(hash_obj* self)
    
    FREE(self);
 }
-*/
 
 ///////////////////////////////////////////////////////////////////////
 // nbVACeԂ
@@ -103,6 +102,7 @@ static unsigned int get_hash_value(hash_obj* self, char* key)
 static void resize(hash_obj* self) 
 {
     self->mTableSize *= 5;
+    FREE(self->mTable);
     self->mTable = (hash_it**)MALLOC(sizeof(hash_it*) * self->mTableSize);
     memset(self->mTable, 0, sizeof(hash_it*)*self->mTableSize);
 
