@@ -9,9 +9,9 @@
 #include "saphire_extra.h"
 #include <wchar.h>
 
-enum eKanjiCode { kEucjp, kSjis, kUtf8, kUtf8Mac, kUnknown };
-extern char* gKanjiCodeString[5];
-extern char* gIconvKanjiCodeName[5];     // ICONVの漢字コードの名前
+enum eKanjiCode { kEucjp, kSjis, kUtf8, kUtf8Mac, kByte, kUnknown };
+extern char* gKanjiCodeString[6];
+extern char* gIconvKanjiCodeName[6];     // ICONVの漢字コードの名前
 
 void kanji_init();     // 初期化
 void kanji_final();    // 解放
@@ -28,7 +28,7 @@ extern int is_hankaku(enum eKanjiCode code, unsigned char c);
     // 引数が半角文字一バイト目かどうか
 extern int is_kanji(enum eKanjiCode code, unsigned char c);
     // 引数が漢字一バイト目かどうか
-extern int is_all_ascii(char* buf);
+int is_all_ascii(enum eKanjiCode code, char* buf);
     // FALSE:漢字まじり TRUE:全部英数字
 
 extern int str_termlen(enum eKanjiCode code, char* mbs);
